@@ -1068,6 +1068,8 @@ class SimpleDataVars():
                 val = str(val)
                 if val == "":
                     return []
+                elif val.startswith('\n') or val.startswith(' \n'):
+                    return [{x.split(':')[0]: list(map(str.strip, x.split(':', maxsplit=1)[1].split(','))) for x in val.split("\n") if len(x)>2}]
                 return [fixEmpty(x) for x in val.split(delimeter)]
 
             return wrapper
@@ -1086,9 +1088,9 @@ class SimpleDataVars():
         """
         if "humanreadable" in kw:
             hr = kw['humanreadable']
-            return list(zip(*(self.Get(x, humanreadable=hr) for x in argvVarNames)))
+            return list(zip(*(self.Get(x, humanreadable=hr)if isinstance(x, str) else x for x in argvVarNames)))
         else:
-            return list(zip(*(self.Get(x) for x in argvVarNames)))
+            return list(zip(*(self.Get(x) if isinstance(x, str) else x for x in argvVarNames)))
 
     def select(self, *fields, **kw):
         """
