@@ -14,12 +14,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import re
-from calculate.lib.cl_xml import xpath
+from ..cl_xml import xpath, xmlDoc, insertBefore
 from .generic import objShare
-from calculate.lib.cl_xml import xmlDoc
-
 
 class procmail(objShare):
     """Класс для обработки конфигурационного файла типа  procmail
@@ -45,10 +42,10 @@ class procmail(objShare):
         for node in xmlFields:
             # Добавление перевода строк в если его нет между полями
             if (self.docObj.getTypeField(node) == "var" and
-                    node.previousSibling and
-                    (self.docObj.getTypeField(node.previousSibling) not in
+                    node.getprevious() is not None and
+                    (self.docObj.getTypeField(node.getprevious()) not in
                         ("br", "comment"))):
-                self.docObj.body.insertBefore(self.docObj.createField(
+                insertBefore(self.docObj.body, self.docObj.createField(
                     "br", [], "", [], False, False), node)
 
     def setDataField(self, txtLines, endtxtLines):
@@ -100,15 +97,15 @@ class procmail(objShare):
                     fieldXML = self.createFieldTerm(field.name,
                                                     field.value,
                                                     field.br, docObj)
-                    nodeBody.appendChild(fieldXML)
+                    nodeBody.append(fieldXML)
                     if field.br[-1] == "\n":
                         fieldXMLBr = docObj.createField(
                             "br", [], "", [], False, False)
-                        nodeBody.appendChild(fieldXMLBr)
+                        nodeBody.append(fieldXMLBr)
                 elif field.comment is not False:
                     fieldXML = docObj.createField(
                         "comment", [field.comment], "", [], False, False)
-                    nodeBody.appendChild(fieldXML)
+                    nodeBody.append(fieldXML)
                 elif field.br is not False:
                     brText = field.br.replace("\n", "")
                     if brText:
@@ -117,7 +114,7 @@ class procmail(objShare):
                     else:
                         fieldXML = docObj.createField(
                             'br', [], "", [], False, False)
-                    nodeBody.appendChild(fieldXML)
+                    nodeBody.append(fieldXML)
         return docObj
 
     def join(self, procmailObj):
