@@ -161,10 +161,10 @@ def getInstalledVideo(prefix="/"):
 
 def getDistfilesVideo(prefix="/"):
     """Get video drivers from distfiles"""
-    if os.path.isdir(path.join(prefix, 'var/db/repos/gentoo')):
+    if listDirectory(path.join(prefix, "var/calculate/distfiles")):
         distFiles = path.join(prefix, "var/calculate/distfiles")
     else:
-        distFiles = path.join(prefix, "usr/portage/distfiles")    
+        distFiles = path.join(prefix, "usr/portage/distfiles")
     driver_map = {'ati': 'fglrx',
                   'amd': 'fglrx',
                   'radeon': 'fglrx',
